@@ -70,5 +70,8 @@ struct _GConfEditorWindowClass {
 GType gconf_editor_window_get_type (void);
 GtkWidget *gconf_editor_window_new (void);
 
+void gconf_editor_window_go_to (GConfEditorWindow *window,
+				const char        *location);
+
 #endif /* __GCONF_EDITOR_WINDOW_H__ */
 
